@@ -1,11 +1,5 @@
-#use "topfind";;
-#require "base";;
-#require "stdio";;
-
 let () = Printexc.record_backtrace false
 
-open Base
-open Stdio
 open Ppxlib
 
 module N = Ppxlib_private.Name
@@ -15,9 +9,9 @@ module N = Ppxlib.Ppxlib_private.Name
 
 
 let dot_suffixes name =
-  Caml.Printf.sprintf "%s"
-    (Sexp.to_string_hum
-       (List.sexp_of_t String.sexp_of_t (N.dot_suffixes name)))
+  Printf.sprintf "%s"
+    (Sexplib0.Sexp.to_string_hum
+       (Sexplib0.Sexp_conv.sexp_of_list Sexplib0.Sexp_conv.sexp_of_string (N.dot_suffixes name)))
 [%%expect{|
 val dot_suffixes : string -> string = <fun>
 |}]
@@ -35,9 +29,9 @@ let _ = dot_suffixes "foo.@bar.baz"
 
 let split_path name =
     let a, b = N.split_path name in
-    Caml.Printf.sprintf "%s"
-      (Sexp.to_string_hum
-         (List [sexp_of_string a; Option.sexp_of_t sexp_of_string b]))
+    Printf.sprintf "%s"
+      (Sexplib0.Sexp.to_string_hum
+         (List [Sexplib0.Sexp_conv.sexp_of_string a; Sexplib0.Sexp_conv.sexp_of_option Sexplib0.Sexp_conv.sexp_of_string b]))
 [%%expect{|
 val split_path : string -> string = <fun>
 |}]
@@ -150,3 +144,32 @@ let _ = Ppxlib.Code_path.to_string_path complex_path
 [%%expect{|
 - : string = "dir/main.ml.Sub.Sub_sub"
 |}]
+
+let _ =
+  let a = gen_symbol () ~prefix:"__prefix__" in
+  let b = gen_symbol () ~prefix:a in
+  a, b
+[%%expect{|
+- : string * string = ("__prefix____001_", "__prefix____002_")
+|}]
+
+let _ =
+  let open Ast_builder.Make (struct let loc = Location.none end) in
+  let params decl =
+    List.map (fun (core_type, _) -> core_type.ptyp_desc) decl.ptype_params
+  in
+  let decl =
+    type_declaration
+      ~name:{ txt = "t"; loc = Location.none }
+      ~params:(List.init 3 (fun _ -> ptyp_any, (NoVariance, NoInjectivity)))
+      ~cstrs:[]
+      ~kind:Ptype_abstract
+      ~private_:Public
+      ~manifest:None
+  in
+  params decl, params (name_type_params_in_td decl)
+[%%expect{|
+- : core_type_desc list * core_type_desc list =
+([Ptyp_any; Ptyp_any; Ptyp_any],
+ [Ptyp_var "a__003_"; Ptyp_var "b__004_"; Ptyp_var "c__005_"])
+|}]
